function [bvp,info]=setBVPElectrostatic2D01(N,varargin)
  [default_geodir,default_meshdir]=fc_vfemp1.default_directories(2);
  p = inputParser; 
  p.addParamValue('sigma1',1,@isscalar); 
  p.addParamValue('sigma2',10,@isscalar);
  p.addParamValue('verbose',0,@isscalar); % select labels to draw
  p.addParamValue('geodir',default_geodir,@ischar); 
  p.addParamValue('meshdir',default_meshdir,@ischar);
  p.parse(varargin{:});
  R=p.Results;
  sigma1=R.sigma1;sigma2=R.sigma2;verbose=R.verbose;
  geofile='square4holes6dom.geo';
  dim=2;d=2;
  if verbose>=1
    fprintf('------------------------------------------------------\n'); 
    fprintf('      2D electrostatic BVP problem \n');
    fprintf('        on square [-1,1]x[-1,1] with \n');
    fprintf('        4 holes and 6 domains \n');
    fprintf('------------------------------------------------------\n'); 
    fprintf(' PDE :\n');
    fprintf('    * -div(sigma grad(phi)) = 0   on domain [2,4,6,8,10,20]\n')
    fprintf(' Local electrical conductivity : \n');
    fprintf('    * sigma=sigma1=%g on domain [10]\n',sigma1);
    fprintf('    * sigma=sigma2=%g on domain [2,4,6,8,20]\n',sigma2);
    fprintf(' Dirichlet boundary condition on boundaries [1,3,5,7]\n');
    fprintf('    * on [1,5] : phi = 12\n');
    fprintf('    * on [3,7] : phi = 0\n');
    fprintf(' Neumann boundary condition on boundary [20]\n');
    fprintf('    * on [20] : sigma d(phi)/dn = 0\n');
    fprintf('------------------------------------------------------\n'); 
    if verbose==10, return;end
  end
  if verbose>=2,fprintf('1. Building the mesh using GMSH\n  -> from %s.geo\n',geofile);end
  tstart=tic();
  meshfile=gmsh.buildmesh(geofile,N,'d',d,'geodir',R.geodir,'meshdir',R.meshdir);%,'force',true)
  Th=siMesh(meshfile,'dim',2,'format','gmsh');
  tcpu(1)=toc(tstart);
  if verbose>=2
    fprintf('     Mesh sizes : nq=%d, nme=%d, h=%.3e\n',Th.nq,Th.get_nme(),Th.get_h());
    fprintf('2. Setting 2D Electrostatic BVP\n');
  end
  tstart=tic();
  Lop=Loperator(dim,d,{sigma2,0;0,sigma2},[],[],[]);
  pde=PDEelt(Lop);
  bvp=BVP(Th,pde);
  Lop=Loperator(dim,d,{sigma1,0;0,sigma1},[],[],[]);
  pde=PDEelt(Lop);
  bvp.setPDE(2,10,pde);
  bvp.setDirichlet( 1, 12);
  bvp.setDirichlet( 3, 0);
  bvp.setDirichlet( 5, 12);
  bvp.setDirichlet( 7, 0);
  tcpu(2)=toc(tstart);

  info.tcpu=tcpu;
  info.sigma1=R.sigma1;
  info.sigma1=R.sigma2;
end